function Rf=GIBBS_ASSET_2_MIX_SIM(R_hist,ndraws, burn_in)


if nargin<2,    ndraws=50000;                                          end
if nargin<3,    burn_in=ndraws*0.1;                                  end

[nobs,dim]=size(R_hist);


%----------------------------------------
% Prior setup
prior_mu=zeros(dim,1);
prior_V=5*eye(dim,dim);
prior_omega=eye(dim);
prior_df=dim+5;
prior_P_a=1;
prior_P_b=1;
%-----------------------------------------

beta1=zeros(dim,ndraws);
beta2=zeros(dim,ndraws);
sigma1=zeros(dim,dim,ndraws);
sigma2=zeros(dim,dim,ndraws);
Prob=zeros(1,ndraws);

beta1(:,1)=mean(R_hist);
beta2(:,1)=beta1(:,1);
sigma1(:,:,1)=cov(R_hist);
sigma2(:,:,1)=sigma1(:,:,1);
inv_sigma1=inv(sigma1(:,:,1));
inv_sigma2=inv(sigma2(:,:,1));
tau=rand(nobs,1)<0.5;
Prob(1)=0.5;


inv_prior_V=inv(prior_V);
V_mu=inv_prior_V*prior_mu;
inv_prior_omega=inv(prior_omega);


% Gibbs sampler
for m=2:ndraws  
        
    use_index=tau;
    R_use=R_hist(use_index,:);
    nobs1=sum(use_index);
              
    D= nobs1*inv_sigma1+inv_prior_V; 
    d=inv_sigma1*sum(R_use,1)'+V_mu; 
    P=chol(D);
    beta_draw=D\d+P\randn(dim,1);
    beta1(:,m)=beta_draw ;
                 
    resid_matrix=R_use-beta_draw(:,ones(nobs1,1))';
    RSS_matrix=resid_matrix'*resid_matrix;    
    post_omega=inv(inv_prior_omega+RSS_matrix);
    inv_sigma1=WISHART_RND1(post_omega,nobs1+prior_df);   
    sigma1(:,:,m)=inv(inv_sigma1);
    
    use_index=~tau;
    R_use=R_hist(use_index,:);
    nobs2=sum(use_index);
         
    D= nobs2*inv_sigma2+inv_prior_V; 
    d=inv_sigma2*sum(R_use,1)'+V_mu; 
    P=chol(D);
    beta_draw=D\d+P\randn(dim,1);
    beta2(:,m)=beta_draw ;
                 
    resid_matrix=R_use-beta_draw(:,ones(nobs2,1))';
    RSS_matrix=resid_matrix'*resid_matrix;    
    post_omega=inv(inv_prior_omega+RSS_matrix);
    inv_sigma2=WISHART_RND1(post_omega,nobs2+prior_df);
    sigma2(:,:,m)=inv(inv_sigma2);
       
    density1=Prob(m-1)*MVN_PDF(R_hist', beta1(:,m), sigma1(:,:,m));
    density2=(1-Prob(m-1))*MVN_PDF(R_hist', beta2(:,m), sigma2(:,:,m));
    post_tau1= density1./( density1+ density2);
    tau=rand(nobs,1)<post_tau1';
        
    Prob(m)=betarnd( prior_P_a+nobs1, prior_P_b+nobs2);  
      
end

  
beta1=beta1(:,burn_in+1:ndraws);
beta2=beta2(:,burn_in+1:ndraws);
sigma1=sigma1(:,:,burn_in+1:ndraws);
sigma2=sigma2(:,:,burn_in+1:ndraws);
Prob=Prob(:,burn_in+1:ndraws);



% Predictive distribution
%------------------------
[dim,ndraws]=size(beta1); 
tau_f=rand(1,ndraws)<Prob;
Rf=zeros(dim,ndraws);
for m=1:ndraws
    if tau_f(m)==1
        P=chol(sigma1(:,:,m));
        Rf(:,m)=beta1(:,m)+P'*randn(dim,1);
    else
        P=chol(sigma2(:,:,m));
        Rf(:,m)=beta2(:,m)+P'*randn(dim,1);
    end    
end

