function [betta,sigma,Prob,Rf]=GIBBS_ASSET_N_MIX(R_hist,nmix,ndraws, burn_in)



if nargin<2,    nmix=2;                                                     end
if nargin<3,    ndraws=50000;                                          end
if nargin<4,    burn_in=ndraws*0.1;                                  end

[nobs,dim]=size(R_hist);


%----------------------------------------
% Prior setup
prior_mu=zeros(dim,1);
prior_V=5*eye(dim,dim);
prior_omega=eye(dim);
prior_df=dim+5;
prior_P=ones(nmix,1);
%-----------------------------------------


betta=zeros(dim,ndraws,nmix);
sigma=zeros(dim,dim,ndraws,nmix);
Prob=zeros(nmix,ndraws);

nobs_mix=zeros(nmix,1);
inv_sigma=zeros(dim,dim,nmix);
density=zeros(nobs,nmix);

R_hist_mean=mean(R_hist)';
R_hist_cov=cov(R_hist);
betta(:,1,:)=R_hist_mean(:,ones(nmix,1));
sigma(:,:,1,:)=R_hist_cov(:,:,ones(nmix,1));
for m=1:nmix
    inv_sigma(:,:,m)=inv(sigma(:,:,1,m));
end
tau=ceil(nmix*rand(nobs,1));
Prob(1)=1/nmix;


inv_prior_V=inv(prior_V);
V_mu=inv_prior_V*prior_mu;
inv_prior_omega=inv(prior_omega);
R_hist_trans=R_hist';

% Gibbs sampler
H_status_bar=waitbar(0,'In progress   0%');
percentage=floor(ndraws/100);
for m=2:ndraws
    
    if mod(m,percentage)==0
        waitbar(m/ndraws,H_status_bar,['In progress   ',num2str(floor(m/ndraws*100)),'%']);
    end
    
    for k=1:nmix
        
        use_index= tau==k;
        R_use=R_hist(use_index,:);
        nobs_mix(k)=sum(use_index);        
                 
        D= nobs_mix(k)*inv_sigma(:,:,k)+inv_prior_V; 
        d= inv_sigma(:,:,k)*sum(R_use,1)'+V_mu; 
        P=chol(D);
        beta_draw=D\d+P\randn(dim,1);
        betta(:,m,k)=beta_draw ;    
                
        resid_matrix=R_use-beta_draw(:,ones(nobs_mix(k),1))';
        RSS_matrix=resid_matrix'*resid_matrix;    
        post_omega=inv(inv_prior_omega+RSS_matrix);
        inv_sigma(:,:,k)=WISHART_RND1(post_omega,nobs_mix(k)+prior_df);
        sigma_draw=inv(inv_sigma(:,:,k));
        sigma(:,:,m,k)=sigma_draw ;        
        
        density(:,k)=Prob(k,m-1)*MVN_PDF(R_hist_trans, beta_draw, sigma_draw)';
        
    end            
       
    W_sum=sum(density,2);
    W=density./W_sum(:,ones(nmix,1));
    cum_W=cumsum(W,2);
    
    U=rand(nobs,1);
    U_matrix=U(:,ones(nmix,1));
    tau=sum(cum_W<U_matrix,2)+1;    
       
    Prob(:,m)=DIRICHLET_RND(prior_P+nobs_mix);  
      
end

   
betta=betta(:,burn_in+1:ndraws,:);
sigma=sigma(:,:,burn_in+1:ndraws,:);
Prob=Prob(:,burn_in+1:ndraws);


beta_mean=mean(betta,2);
beta_std=std(betta,0,2);
sigma_mean=mean(sigma,3);
Prob_mean=mean(Prob,2);
Prob_std=std(Prob,0,2);


% display the result
for n=1:nmix
    disp(['Regime ',num2str(n),''])
    result=cell(dim+1,3);
    result(1,:)={'variable','mean',' std'};           
    for m=1:dim
        result(m+1,1)={['(',num2str(m),')']};
        result(m+1,2:3)={beta_mean(m,1,n),beta_std(m,1,n)};
    end    
    disp(' ')
    disp(result)
end

disp('Regime prob')
result=cell(nmix+1,3);
result(1,:)={'variable','mean',' std'};         
for m=1:nmix
    result(m+1,1)={['P(',num2str(m),')']};
    result(m+1,2:3)={Prob_mean(m),Prob_std(m)};
end
disp(' ')
disp(result)


disp('Covariance matrix')
for n=1:nmix
    for m=1:dim
        fprintf('%8.2f', sigma_mean(m,:,1,n))
        fprintf('\n')
    end
    fprintf('\n')
end


close(H_status_bar);


% predictive distribution
%------------------------
[dim,ndraws,nmix]=size(betta);
cum_Prob=cumsum(Prob);
U=rand(1,ndraws);
U_matrix=U(ones(nmix,1),:);
tau_f=sum(cum_Prob<U_matrix)+1;


Rf=zeros(dim,ndraws);
for m=1:ndraws
    model=tau_f(m);
    cov_mat=sigma(:,:,m,model);
    P=chol(cov_mat);
    Rf(:,m)=betta(:,m,model)+P'*randn(dim,1);
end

Rf_mean=mean(Rf,2);
Rf_std=std(Rf,0,2);

disp('Predictive distribution')
result=cell(dim+1,3);
result(1,:)={'variable','mean',' std'};           
for m=1:dim
    result(m+1,1)={['Rf(',num2str(m),')']};
    result(m+1,2:3)={Rf_mean(m),Rf_std(m)};
end
disp(' ')
disp(result)
