function [betta,sigma,Rf]=GIBBS_ASSET_SUR(R_hist,ndraws, burn_in)


if nargin<2,    ndraws=50000;                                          end
if nargin<3,    burn_in=ndraws*0.1;                                  end

[nobs,dim]=size(R_hist);

%----------------------------------------
% Prior setup
prior_mu=zeros(dim,1);
prior_V=10*eye(dim,dim);
prior_omega=eye(dim);
prior_df=dim+5;

%-----------------------------------------

betta=zeros(dim,ndraws);
sigma=zeros(dim,dim,ndraws);

betta(:,1)=mean(R_hist);
sigma(:,:,1)=cov(R_hist);
inv_sigma=inv(sigma(:,:,1));

inv_prior_V=inv(prior_V);
V_mu=inv_prior_V*prior_mu;
inv_prior_omega=inv(prior_omega);
R_sum=sum(R_hist)';


% Gibbs sampler
H_status_bar=waitbar(0,'In progress   0%');
percentage=floor(ndraws/100);
for m=2:ndraws
    
    if mod(m,percentage)==0
        waitbar(m/ndraws,H_status_bar,['In progress   ',num2str(floor(m/ndraws*100)),'%']);
    end    
            
    D=nobs*inv_sigma+inv_prior_V; 
    d=(inv_sigma*R_sum+V_mu); 
    P=chol(D);
    beta_draw=D\d+P\randn(dim,1);
    betta(:,m)=beta_draw;
    
    
    resid_matrix=R_hist-beta_draw(:,ones(nobs,1))';
    RSS_matrix=resid_matrix'*resid_matrix;    
    post_omega=inv(inv_prior_omega+RSS_matrix);
    inv_sigma=WISHART_RND1(post_omega,nobs+prior_df);
    sigma(:,:,m)=inv(inv_sigma);
      
end
close(H_status_bar);

   
betta=betta(:,burn_in+1:ndraws);
sigma=sigma(:,:,burn_in+1:ndraws);



beta_mean=mean(betta,2);
beta_std=std(betta,0,2);
sigma_mean=mean(sigma,3);


% display the result
result=cell(dim+1,3);
result(1,:)={'Variable',' post.mean',' post.std'};           
for m=1:dim
    result(m+1,1)={['R(',num2str(m),')']};
    result(m+1,2:3)={beta_mean(m),beta_std(m)};
end
disp(' ')
disp(result)

disp('covariance matrix')
for m=1:dim
    fprintf('%8.2f', sigma_mean(m,:))
    fprintf('\n')
end
fprintf('\n')



% Predictive distribution Rf
%------------------------
[dim,ndraws]=size(betta);
Rf=zeros(dim,ndraws);
for m=1:ndraws
   P=chol(sigma(:,:,m));
   Rf(:,m)=betta(:,m)+P'*randn(dim,1);
end

Rf_mean=mean(Rf,2);
Rf_std=std(Rf,0,2);

disp('Predictive distribution Rf')
result=cell(dim+1,3);
result(1,:)={'variable','mean',' std'};           
for m=1:dim
    result(m+1,1)={['Rf(',num2str(m),')']};
    result(m+1,2:3)={Rf_mean(m),Rf_std(m)};
end
disp(' ')
disp(result)
