clear all


[price,header]=xlsread('stock_price_data.xls');
%price=price(1:2010,:); % 2000-2007, 9 countries
R=diff(log(price))*100;
[nobs,dim]=size(R);

% Posterior Esimation
nmix=3;
ndraws=20000;
[betta,sigma,Prob,Rf]=GIBBS_ASSET_N_MIX(R,nmix,ndraws);

% Calculate mean-variance frontier
Rf_mean=mean(Rf,2);
Rf_cov=cov(Rf');
Rp= -0.08:0.001:0.09;
[Wp_BAY,Vp_BAY]=MV_FRONT(Rf_mean,Rf_cov,Rp);
[Wp_CE,Vp_CE]=MV_FRONT(mean(R),cov(R),Rp);
plot([Vp_BAY;Vp_CE],Rp)

% optimal portfolio by EU-max
w0=1/(dim-1)*ones(dim-1,1);
w0_pos=w0;
options = optimset('LargeScale','off','MaxFunEvals',10000,'Display','off'); 
ntype=8;
W_optimal=zeros(dim-1,ntype);
W_optimal_pos=zeros(dim-1,ntype);

H_status_bar=waitbar(0,'In Progress   ');
for m=1:ntype
    
    waitbar(m/ntype,H_status_bar,['In Progress   ',num2str(m),' / ',num2str(ntype)]);
    
    ARA=m;
    W_optimal(:,m)=fminunc(@(w)EU_MAX(w,Rf,ARA),w0,options);  
    W_optimal_pos(:,m)=fmincon(@(w)EU_MAX(w,Rf,ARA),w0_pos,[],[],[],[],zeros(dim-1,1),ones(dim-1,1));    
    
    w0=W_optimal(:,m);
    w0_pos=W_optimal_pos(:,m);
end
close(H_status_bar);

W_optimal=[W_optimal;1-sum(W_optimal)]*100;
W_optimal_pos=[W_optimal_pos;1-sum(W_optimal_pos)]*100;

disp('EU-max portfolio ')

for m=1:dim    
    fprintf('R(%1.0f) \t',m)
    fprintf('%8.2f', W_optimal(m,:))
    fprintf('\n')
end
fprintf('\n')

disp('EU-max portfolio without shortsell ')

for m=1:dim    
    fprintf('R(%1.0f) \t',m)
    fprintf('%8.2f', W_optimal_pos(m,:))
    fprintf('\n')
end
fprintf('\n')


% Gererate a report
header=header(1,2:end);
for m=1:dim
    temp_str=header{m};
    header{m}=temp_str(1:strfind(temp_str,'_')-1);
end

R_mean=mean(betta,2);
R_std=std(betta,0,2);
xlswrite('Portfolio selection',header,1,'B1')
xlswrite('Portfolio selection',{'Regime 1';'Post.mean';'Post.std';'Regime 2';'Post.mean';'Post.std';'Regime 3';'Post.mean';'Post.std'},1,'A2')
xlswrite('Portfolio selection',[nan(1,dim);R_mean(:,:,1)';R_std(:,:,1)';nan(1,dim);R_mean(:,:,2)';R_std(:,:,2)';nan(1,dim);R_mean(:,:,3)';R_std(:,:,3)'],1,'B2')


Rf_std=sqrt(diag(Rf_cov));
Rf_plus=mean(Rf>0,2);
xlswrite('Portfolio selection',{'Mean','Std','Pr(R>0)'},2,'B1')
xlswrite('Portfolio selection',header',2,'A2')
xlswrite('Portfolio selection',[Rf_mean,Rf_std,Rf_plus],2,'B2')

risk_averse=cell(1,ntype);
for m=1:ntype
    risk_averse{m}=[' = ',num2str(m)];
end
xlswrite('Portfolio selection',risk_averse,3,'B1')
xlswrite('Portfolio selection',header',3,'A2')
xlswrite('Portfolio selection',W_optimal,3,'B2')

xlswrite('Portfolio selection',risk_averse,4,'B1')
xlswrite('Portfolio selection',header',4,'A2')
xlswrite('Portfolio selection',W_optimal_pos,4,'B2')