clear all
warning off


[price,header]=xlsread('stock_price_data.xls');
R=diff(log(price))*100;

% descriptive statistics
[nobs,dim]=size(R);
R_mean=mean(R);
R_cov=cov(R);
R_skew=skewness(R);
R_kurtosis= kurtosis(R);

fprintf('mean \t')
fprintf('%8.2f', R_mean)
fprintf('\n')
fprintf('skew \t')
fprintf('%8.2f', R_skew)
fprintf('\n')
fprintf('kurt \t')
fprintf('%8.2f', R_kurtosis)
fprintf('\n')
fprintf('\n')

figure(1)
for m=1:dim
    subplot(3,3,m),hist(R(:,m),40);
end

disp('covariance matrix: ')
for m=1:dim
    fprintf('%8.2f', R_cov(m,:))
    fprintf('\n')
end
fprintf('\n')


% Nomality test: Lilliefors (empirical KS); Jarque-Bera
stat_LI=zeros(1,dim);
p_LI=zeros(1,dim);
stat_JB=zeros(1,dim);
p_JB=zeros(1,dim);
for m=1:dim
    [accept_LI,p_LI(m),stat_LI(m)] = lillietest(R(:,m));
    [accept_JB,p_JB(m),stat_JB(m)] = jbtest(R(:,m));
end

disp('Lilliefors (empirical KS) test: ')
fprintf('%9.3f', stat_LI)
fprintf('\n')
fprintf('%9.3f', p_LI)
fprintf('\n')
fprintf('\n')

disp('Jarque-Bera test: ')
fprintf('%10.1f', stat_JB)
fprintf('\n')
fprintf('%10.3f', p_JB)
fprintf('\n')
fprintf('\n')

% Bayesian residual test
[betta,sigma,Rf]=GIBBS_ASSET_SUR(R,20000,15000);
[dim,ndraws]=size(betta);
stat_KS=zeros(1,ndraws);
H_status_bar=waitbar(0,'In progress   0%');
figure (2)
for m=1:dim
    
    waitbar(m/dim,H_status_bar,['In progress   ',num2str(m),' / ',num2str(dim)]);
    
    for n=1:ndraws
        resid=(R(:,m)-betta(m,n))/sqrt(sigma(m,m,n));
        [accept_KS,p_KS,stat_KS(n)] = kstest(resid);
    end    
    subplot(3,3,m),hist(stat_KS,20); 
    
    % KS approximated 99% critical value 1.63/sqrt(n)
    critical_val=1.63/sqrt(nobs);
    percentile=mean(stat_KS>critical_val)*100;
    disp(['R(',num2str(m),'): ',num2str(percentile),'% simulators exceed 99% KS critical value'])
    
end
close(H_status_bar);


% Gererate a report
header=header(1,2:end);
for m=1:dim
    temp_str=header{m};
    header{m}=temp_str(1:strfind(temp_str,'_')-1);
end
xlswrite('Descriptive Statistics',header,1,'B1')
xlswrite('Descriptive Statistics',{'Mean';'Skewness';'Kurtosis';'';'Lilliefors';'p';'';'Jarque-Bera';'p'},1,'A2')
xlswrite('Descriptive Statistics',[R_mean;R_skew;R_kurtosis;nan(1,dim);stat_LI;p_LI;nan(1,dim);stat_JB;p_JB],1,'B2')

xlswrite('Descriptive Statistics',header,2,'B1')
xlswrite('Descriptive Statistics',header',2,'A2')
xlswrite('Descriptive Statistics',R_cov,2,'B2')

xlswrite('Descriptive Statistics',header,3,'B1')
xlswrite('Descriptive Statistics',{'Post. Mean';'Post. Std';'';'Pred. Mean';'Pred. Std'},3,'A2')
xlswrite('Descriptive Statistics',[mean(betta,2)';std(betta,0,2)';nan(1,dim);mean(Rf,2)';std(Rf,0,2)'],3,'B2')

