clear all


[price,header]=xlsread('stock_price_data.xls');
R=diff(log(price))*100;
price(1,:)=[];
[nobs,dim]=size(R);
 
ARA=2;
window=1000;
rebalance=180;
fund_ini=10000;
trans_cost=0.005;
nround=floor((nobs-window)/rebalance);

fund_Bay1=zeros(1,nround+1);
fund_Bay1(1)=fund_ini;
fund_Bay2=zeros(1,nround+1);
fund_Bay2(1)=fund_ini;
fund_CE=zeros(1,nround+1);
fund_CE(1)=fund_ini;

shares_Bay1=zeros(dim,nround);
shares_Bay2=zeros(dim,nround);
shares_CE=zeros(dim,nround);


W_optimal_Bay2=zeros(dim,1);
weight=1/(dim-1)*ones(dim-1,1);

options = optimset('LargeScale','off','Display','off');
H_status_bar=waitbar(0,'In progress   0%');

for m=1:nround
    
    waitbar(m/nround,H_status_bar,['In Progress   ',num2str(m),' / ',num2str(nround)]);
        
    R_use=R((m-1)*rebalance+1:(m-1)*rebalance+window,:);
    price_now=price((m-1)*rebalance+window,:)';
    price_future=price(m*rebalance+window,:);
    
    % Bayesian 2 regime
    Rf=GIBBS_ASSET_2_MIX_SIM(R_use,80000,30000);
    weight=fminunc(@(w)EU_MAX(w,Rf,ARA),weight,options);
    W_optimal_Bay2(1:end-1)=weight;
    W_optimal_Bay2(end)=1-sum(weight);    
    shares_Bay2(:,m)=fund_Bay2(m)*W_optimal_Bay2./price_now;
    fund_Bay2(m+1)=price_future*shares_Bay2(:,m);
        
    % Bayesian 1 regime
    % max E(Rp)-0.5*ARA*Var(Rp)
    Rf=GIBBS_ASSET_SIM(R_use,10000,5000);
    Rp= -0.20:0.001:0.20;
    [Wp,Vp]=MV_FRONT(mean(Rf,2),cov(Rf'),Rp);
    [max_val,max_index]=max(Rp-0.5*ARA*Vp);
    W_optimal_Bay1=Wp(:,max_index);
    shares_Bay1(:,m)=fund_Bay1(m)*W_optimal_Bay1./price_now;
    fund_Bay1(m+1)=price_future*shares_Bay1(:,m);
    
    % Certainty Equivlence
    % max E(Rp)-0.5*ARA*Var(Rp)
    Rp= -0.20:0.001:0.20;
    [Wp,Vp]=MV_FRONT(mean(R_use)',cov(R_use),Rp);
    [max_val,max_index]=max(Rp-0.5*ARA*Vp);
    W_optimal_CE=Wp(:,max_index);
    shares_CE(:,m)=fund_CE(m)*W_optimal_CE./price_now;
    fund_CE(m+1)=price_future*shares_CE(:,m);    
          
end
close(H_status_bar);


price_use=price(window:rebalance:end,:);
shares_Bay2=[zeros(dim,1),shares_Bay2,zeros(dim,1)];
shares_Bay1=[zeros(dim,1),shares_Bay1,zeros(dim,1)];
shares_CE=[zeros(dim,1),shares_CE,zeros(dim,1)];

% calculate the turnover amount (may larger than fund due to short sell) 
turnover_Bay2=sum(price_use.*abs(diff(shares_Bay2')),2)';
turnover_Bay1=sum(price_use.*abs(diff(shares_Bay1')),2)';
turnover_CE=sum(price_use.*abs(diff(shares_CE')),2)';

% calculate transction-cost adjusted wealth
fund_Bay2_TC=fund_Bay2-cumsum(turnover_Bay2)*trans_cost;
fund_Bay1_TC=fund_Bay1-cumsum(turnover_Bay1)*trans_cost;
fund_CE_TC=fund_CE-cumsum(turnover_CE)*trans_cost;

% calculate the turnover ratio (may larger than 1 due to short sell)

turnover_ratio_Bay2=turnover_Bay2./fund_Bay2_TC*100;
turnover_ratio_Bay1=turnover_Bay1./fund_Bay1_TC*100;
turnover_ratio_CE=turnover_CE./fund_CE_TC*100;


figure (1)
hold on
plot(1:nround+1,fund_CE,':r','LineWidth',2)
plot(1:nround+1,fund_Bay1,'--g','LineWidth',2)
plot(1:nround+1,fund_Bay2,'-b','LineWidth',2)
hold off

figure (2)
hold on
plot(1:nround+1,fund_CE_TC,':r','LineWidth',2)
plot(1:nround+1,fund_Bay1_TC,'--g','LineWidth',2)
plot(1:nround+1,fund_Bay2_TC,'-b','LineWidth',2)
hold off

figure (3)
hold on
plot(1:nround+1,turnover_ratio_CE,':r','LineWidth',2)
plot(1:nround+1,turnover_ratio_Bay1,'--g','LineWidth',2)
plot(1:nround+1,turnover_ratio_Bay2,'-b','LineWidth',2)
hold off